<?php
session_start();
require_once 'include/bd_pdo.php';
require_once 'classes/MainMenu.php';
require_once './classes/SGI.php';
require_once 'classes/Template.php';
require_once 'classes/ValidaSesion.php';

//CONSTANTES Y VARIABLES GLOBALES
$menu = 43;
$submenu = 431;
$titulo = '';

if (!isset($_SESSION['usuario_id']))
    ValidaSesion::salirPagina();
else{
    if(isset($_SESSION['usuario_id']))
        $objSesion = new ValidaSesion($pdo, $submenu);
    else 
        ValidaSesion::salirPagina();
}
if (isset($objSesion)) { 
    $titulo = $objSesion->nombrePagina(); ?>
<!DOCTYPE html>
<html>
    <head>
        <title>Alumnos - <?php echo $titulo; ?></title>
        <?php if ($objSesion->tieneAcceso())
            Template::getCSS(array('elementos.css','secciones/horarios.css'));
        else 
            Template::getCSS(); ?>
    </head>
    <body>        
    <?php
    if ($objSesion->tieneAcceso()) {
        $activo = false;
        $periodo = '';
        if (isset($_SESSION['estado']) && isset($_SESSION['periodo']) && $_SESSION['estado'] == 1 ) {
            $activo = true;            
            $grupos_rs = SGI::getGrupos($pdo, $_SESSION['periodo']);
            $profesores_rs = SGI::getDocentes($pdo, $_SESSION['periodo']);
            $planes_rs = SGI::getPlanes($pdo);
            if(isset($_SESSION['periodo_desc']))
                $periodo = ' (' . $_SESSION['periodo_desc'] . ')';        
        } 
    }
    $menuObj = new MainMenu($_SESSION["RolUsuario_id"], $menu, $submenu, $pdo);
    $menuObj->printMenu($titulo);
    if ($objSesion->tieneAcceso()) {    
        if(isset($_SESSION['periodo']) && $activo ){ ?>
        <main class="container-fluid marco d-flex flex-column justify-content-start align-items-center">
             <div class="nav nav-tabs tabGral justify-content-center w-100 d-none" id="menu" role="tablist">
                <button class="tabs nav-link active" data-seccion="1" id="tabGrupos" data-toggle="tab" data-target="#navGrupos" type="button" role="tab" aria-controls="navGrupos" aria-selected="true"><label>Grupos</label></button>
                <button class="tabs nav-link d-none" data-seccion="2" id="tabProfesores" data-toggle="tab" data-target="#navProfesores" type="button" role="tab" aria-controls="navProfesores" aria-selected="false"><label>Profesores</label></button>
                <button class="tabs nav-link" data-seccion="3" id="tabExtras" data-toggle="tab" data-target="#navExtras" type="button" role="tab" aria-controls="navExtras" aria-selected="true"><label>Extraordinarios</label></button>
            </div>
            <div class="tab-content p-2 w-100">
                <div class="tab-pane fade show active" id="navGrupos" role="tabpanel" aria-labelledby="navGrupos">
                    <div class="d-flex flex-row justify-content-center align-items-center px-4 my-4">
                        <label class="lblTit">Grupo:</label>
                        <div id="dlGrupo" class="position-relative datalist" data-id="0">
                            <input id="inputGrupo" class="datalist-input busca" type="text" placeholder="Escribe aquí el grupo" autocomplete="off">
                            <span id="iconGrupo" class="text-primary input-buscar"></span>
                            <ul style="display:none">
                            <?php foreach($grupos_rs as $grupo) {
                                $nombre = '';
                                if($_SESSION['nivel'] == 1)
                                $nombre = $grupo['Grupo_desc'] . ' ' . $grupo['Carrera_prefijo'];
                                else
                                $nombre = $grupo['Grupo_desc'] . ' - ' . $grupo['Carrera_desc'];
                                ?>
                                <li data-id="<?php echo $grupo['Grupo_id'];?>"><?php echo $nombre;?></li>
                            <?php } ?>
                            </ul>
                        </div>
                    </div>
                    <div class="btns align-self-end d-flex d-lg-none flex-row justify-content-end align-items-center mb-2 oculto">
                        <div class="prev inactivo"><span class="ing-caret"></span></div>
                        <div  class="next"><span class="ing-caret"></span></div>
                    </div>
                    <div id="tablaGrupo" class="tabla d-flex flex-column justify-content-center align-items-center w-100 mb-4"></div>
                </div>
                <div class="tab-pane fade" id="navProfesores" role="tabpanel" aria-labelledby="navProfesores">
                    <div class="d-flex flex-row justify-content-center align-items-center px-4 my-4">
                        <label class="lblTit">Profesor:</label>
                        <div id="dlProfesor" class="position-relative datalist" data-id="0">
                            <input id="inputProfesor" class="datalist-input busca" type="text" placeholder="Escribe aquí el nombre del profesor" autocomplete="off">
                            <span id="iconProfesor" class="text-primary input-buscar"></span>
                            <ul style="display:none">
                            <?php foreach($profesores_rs as $profesor) { ?>
                                <li data-id="<?php echo $profesor['Usuario_id'];?>"><?php echo $profesor['Usuario_apellidos'] . ' ' . $profesor['Usuario_nombre']; ?></li>
                            <?php } ?>
                            </ul>
                        </div>
                    </div>
                    <div class="btns align-self-end d-flex d-lg-none flex-row justify-content-end align-items-center mb-2 oculto">
                        <div class="prev inactivo"><span class="ing-caret"></span></div>
                        <div  class="next"><span class="ing-caret"></span></div>
                    </div>
                    <div id="tablaProfesor" class="tabla d-flex flex-column justify-content-center align-items-center w-100 mb-4"></div>
                </div>
                <div class="tab-pane fade" id="navExtras" role="tabpanel" aria-labelledby="navExtras">
                    <div class="d-flex flex-row justify-content-center align-items-center px-4 my-4">
                        <label class="lblTit text-nowrap">Plan de Estudios:</label>
                        <div id="dlPlan" class="position-relative datalist" data-id="0">
                            <input id="inputPlan" class="datalist-input busca" type="text" placeholder="Escribe aquí el plan de estudio" autocomplete="off">
                            <span id="iconPlan" class="text-primary input-buscar"></span>
                            <ul style="display:none">
                            <?php foreach($planes_rs as $plan) { ?>
                                <li data-id="<?php echo $plan['PlanEstudio_id'];?>"><?php echo $plan['Carrera_desc'] . ' | ' . $plan['PlanEstudio_desc']; ?></li>
                            <?php } ?>
                            </ul>
                        </div>
                    </div>
                    <div class="d-flex flex-row justify-content-center align-items-center px-4 my-4">
                        <label class="lblTit">Semestre:</label>
                        <div id="dlSemestre" class="position-relative datalist" data-id="0">
                            <input id="inputSemestre" class="datalist-input busca" type="text" placeholder="Escribe aquí el semestre" autocomplete="off">
                            <span id="iconSemestre" class="text-primary input-buscar"></span>
                            <ul style="display:none">
                            <?php for($sem = 1; $sem < 10; $sem++) { ?>
                                <li data-id="<?php echo $sem; ?>"><?php echo $sem; ?></li>
                            <?php } ?>
                            </ul>
                        </div>
                        <button type="button" id="btnExtras" class="btn btn-azul1 btnIcon ml-2"><span class="ing-ojo mr-1"></span>Mostrar</button>
                    </div>
                    <div id="tablaExtras" class="tabla d-flex flex-column justify-content-center align-items-center w-100 mb-4"></div>
                </div>
            </div>
        </main>
    <?php } else { ?>
        <main class="container-fluid content marco d-flex justify-content-center align-items-center">
            <div class="msgBox d-flex flex-row justify-content-center align-items-center">
                <img src="img/triangulos.svg" class="imgBoxIzq" />
                <img src="img/triangulos.svg" class="imgBoxDer" />
                <hr class="hrArriba">
                <hr class="hrAbajo">
                <div class="d-flex flex-column justify-content-center align-items-center display-5 text-center">
                    <?php if ($activo) { ?>
                    <div>¡Lo sentimos!</div>
                    <div>Aún<span class="text-azul1 mx-1">no</span>se han publicado los horarios</div>
                    <?php } else { ?>
                    <div>¡Lo sentimos!</div>
                    <div>Ya<span class="text-azul1 mx-1">no</span>tienes horarios asignados</div>
                    <?php } ?>
                </div>
            </div>
        </main>
        <?php }
    } else { ?>
        <main class="container-fluid content marco">
            <div class="row justify-content-center" style="min-height: 600px;">
                <img id="errorImg" class="col-sm-3" src="img/nico_error.svg" />
                <div class="col-sm-9 display-4 d-flex flex-row justify-content-center align-items-center text-center">No tienes acceso a ésta página</div>
            </div>
        </main>
    <?php } ?>
        <div style="isolation: isolate;">
        <?php Template::footer(); ?>
        </div>
        <?php if($objSesion->tieneAcceso()) {
            Template::getJS(array('elementos.js', 'secciones/horarios.js'));?>
        <script>
            screen.orientation.addEventListener("change", function(e) {
                if ($('#tabla').children('table').length > 0)
                    ajustaColumnas();
            });
        </script>  
        <?php } else
            Template::getJS();?>        
    </body>
</html>
<?php } else 
    ValidaSesion::salirPagina();